"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.jpButton = exports.Button = void 0;
const tslib_1 = require("tslib");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const button_styles_1 = require("./button.styles");
/**
 * @internal
 */
class Button extends fast_foundation_1.Button {
    connectedCallback() {
        super.connectedCallback();
        if (!this.appearance) {
            this.appearance = 'neutral';
        }
    }
    /**
     * Applies 'icon-only' class when there is only an SVG in the default slot
     *
     * @public
     * @remarks
     */
    defaultSlottedContentChanged(oldValue, newValue) {
        const slottedElements = this.defaultSlottedContent.filter(x => x.nodeType === Node.ELEMENT_NODE);
        if (slottedElements.length === 1 &&
            (slottedElements[0] instanceof SVGElement ||
                slottedElements[0].classList.contains('fa') ||
                slottedElements[0].classList.contains('fas'))) {
            this.control.classList.add('icon-only');
        }
        else {
            this.control.classList.remove('icon-only');
        }
    }
}
tslib_1.__decorate([
    fast_element_1.attr
], Button.prototype, "appearance", void 0);
tslib_1.__decorate([
    fast_element_1.attr({ attribute: 'minimal', mode: 'boolean' })
], Button.prototype, "minimal", void 0);
exports.Button = Button;
/**
 * The button component registration.
 *
 * @public
 * @remarks
 * Generated HTML Element: `<jp-button>`
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/API/ShadowRoot/delegatesFocus | delegatesFocus}
 */
exports.jpButton = Button.compose({
    baseName: 'button',
    baseClass: fast_foundation_1.Button,
    template: fast_foundation_1.buttonTemplate,
    styles: button_styles_1.buttonStyles,
    shadowOptions: {
        delegatesFocus: true
    }
});
//# sourceMappingURL=index.js.map