"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorBase = exports.foregroundOnErrorAlgorithm = exports.errorForegroundAlgorithm = exports.errorFillAlgorithm = exports.ContrastTarget = exports.baseErrorColor = exports.black = exports.white = void 0;
const fast_colors_1 = require("@microsoft/fast-colors");
const fast_components_1 = require("@microsoft/fast-components");
/*
 * The error palette is built using the same color algorithm as the accent palette
 * But by copying the algorithm from @microsoft/fast-components at commit 03d711f222bd816834a5e1d60256d3e083b27c27
 * as some helpers are not exported.
 * The delta used are those of the accent palette.
 */
exports.white = fast_components_1.SwatchRGB.create(1, 1, 1);
exports.black = fast_components_1.SwatchRGB.create(0, 0, 0);
exports.baseErrorColor = fast_colors_1.parseColorHexRGB('#D32F2F');
var ContrastTarget;
(function (ContrastTarget) {
    ContrastTarget[ContrastTarget["normal"] = 4.5] = "normal";
    ContrastTarget[ContrastTarget["large"] = 7] = "large";
})(ContrastTarget = exports.ContrastTarget || (exports.ContrastTarget = {}));
function errorFillAlgorithm(palette, neutralPalette, reference, hoverDelta, activeDelta, focusDelta, neutralFillRestDelta, neutralFillHoverDelta, neutralFillActiveDelta) {
    const error = palette.source;
    const referenceIndex = neutralPalette.closestIndexOf(reference);
    const swapThreshold = Math.max(neutralFillRestDelta, neutralFillHoverDelta, neutralFillActiveDelta);
    const direction = referenceIndex >= swapThreshold ? -1 : 1;
    const errorIndex = palette.closestIndexOf(error);
    const hoverIndex = errorIndex;
    const restIndex = hoverIndex + direction * -1 * hoverDelta;
    const activeIndex = restIndex + direction * activeDelta;
    const focusIndex = restIndex + direction * focusDelta;
    return {
        rest: palette.get(restIndex),
        hover: palette.get(hoverIndex),
        active: palette.get(activeIndex),
        focus: palette.get(focusIndex)
    };
}
exports.errorFillAlgorithm = errorFillAlgorithm;
/**
 * @internal
 */
function errorForegroundAlgorithm(palette, reference, contrastTarget, restDelta, hoverDelta, activeDelta, focusDelta) {
    const error = palette.source;
    const errorIndex = palette.closestIndexOf(error);
    const direction = fast_components_1.isDark(reference) ? -1 : 1;
    const startIndex = errorIndex +
        (direction === 1
            ? Math.min(restDelta, hoverDelta)
            : Math.max(direction * restDelta, direction * hoverDelta));
    const accessibleSwatch = palette.colorContrast(reference, contrastTarget, startIndex, direction);
    const accessibleIndex1 = palette.closestIndexOf(accessibleSwatch);
    const accessibleIndex2 = accessibleIndex1 + direction * Math.abs(restDelta - hoverDelta);
    const indexOneIsRestState = direction === 1
        ? restDelta < hoverDelta
        : direction * restDelta > direction * hoverDelta;
    let restIndex;
    let hoverIndex;
    if (indexOneIsRestState) {
        restIndex = accessibleIndex1;
        hoverIndex = accessibleIndex2;
    }
    else {
        restIndex = accessibleIndex2;
        hoverIndex = accessibleIndex1;
    }
    return {
        rest: palette.get(restIndex),
        hover: palette.get(hoverIndex),
        active: palette.get(restIndex + direction * activeDelta),
        focus: palette.get(restIndex + direction * focusDelta)
    };
}
exports.errorForegroundAlgorithm = errorForegroundAlgorithm;
/**
 * @internal
 */
function foregroundOnErrorAlgorithm(reference, contrastTarget) {
    return reference.contrast(exports.white) >= contrastTarget ? exports.white : exports.black;
}
exports.foregroundOnErrorAlgorithm = foregroundOnErrorAlgorithm;
exports.errorBase = fast_components_1.SwatchRGB.create(exports.baseErrorColor.r, exports.baseErrorColor.g, exports.baseErrorColor.b);
//# sourceMappingURL=colors.js.map