"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.optionStyles = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const styles_1 = require("../styles");
/**
 * Styles for Option
 * @public
 */
const optionStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('inline-flex')} :host {
      align-items: center;
      font-family: ${fast_components_1.bodyFont};
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      border: calc(${fast_components_1.focusStrokeWidth} * 1px) solid transparent;
      box-sizing: border-box;
      color: ${fast_components_1.neutralForegroundRest};
      cursor: pointer;
      flex: 0 0 auto;
      fill: currentcolor;
      font-size: ${fast_components_1.typeRampBaseFontSize};
      height: calc(${styles_1.heightNumber} * 1px);
      line-height: ${fast_components_1.typeRampBaseLineHeight};
      margin: 0 calc(${fast_components_1.designUnit} * 1px);
      outline: none;
      overflow: hidden;
      padding: 0 calc(${fast_components_1.designUnit} * 2.25px);
      user-select: none;
      white-space: nowrap;
    }

    /* TODO should we use outline instead of background for focus to support multi-selection */
    :host(:${fast_foundation_1.focusVisible}) {
      background: ${fast_components_1.accentFillFocus};
      color: ${fast_components_1.foregroundOnAccentFocus};
    }

    :host([aria-selected='true']) {
      background: ${fast_components_1.accentFillRest};
      color: ${fast_components_1.foregroundOnAccentRest};
    }

    :host(:hover) {
      background: ${fast_components_1.accentFillHover};
      color: ${fast_components_1.foregroundOnAccentHover};
    }

    :host(:active) {
      background: ${fast_components_1.accentFillActive};
      color: ${fast_components_1.foregroundOnAccentActive};
    }

    :host(:not([aria-selected='true']):hover),
    :host(:not([aria-selected='true']):active) {
      background: ${fast_components_1.neutralFillHover};
      color: ${fast_components_1.neutralForegroundRest};
    }

    :host([disabled]) {
      cursor: ${fast_foundation_1.disabledCursor};
      opacity: ${fast_components_1.disabledOpacity};
    }

    :host([disabled]:hover) {
      background-color: inherit;
    }

    .content {
      grid-column-start: 2;
      justify-self: start;
      overflow: hidden;
      text-overflow: ellipsis;
    }

    .start,
    .end,
    ::slotted(svg) {
      display: flex;
    }

    ::slotted(svg) {
      /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
      height: calc(${fast_components_1.designUnit} * 4px);
      width: calc(${fast_components_1.designUnit} * 4px);
    }

    ::slotted([slot='end']) {
      margin-inline-start: 1ch;
    }

    ::slotted([slot='start']) {
      margin-inline-end: 1ch;
    }
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        :host {
          border-color: transparent;
          forced-color-adjust: none;
          color: ${fast_web_utilities_1.SystemColors.ButtonText};
          fill: currentcolor;
        }

        :host(:not([aria-selected='true']):hover),
        :host([aria-selected='true']) {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
          color: ${fast_web_utilities_1.SystemColors.HighlightText};
        }

        :host([disabled]),
        :host([disabled]:not([aria-selected='true']):hover) {
          background: ${fast_web_utilities_1.SystemColors.Canvas};
          color: ${fast_web_utilities_1.SystemColors.GrayText};
          fill: currentcolor;
          opacity: 1;
        }
      `));
exports.optionStyles = optionStyles;
//# sourceMappingURL=option.styles.js.map