"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.treeItemStyles = exports.expandCollapseButtonSize = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const index_1 = require("../styles/index");
const ltr = fast_element_1.css `
  .expand-collapse-glyph {
    transform: rotate(0deg);
  }
  :host(.nested) .expand-collapse-button {
    left: var(
      --expand-collapse-button-nested-width,
      calc(${index_1.heightNumber} * -1px)
    );
  }
  :host([selected])::after {
    left: calc(${fast_components_1.focusStrokeWidth} * 1px);
  }
  :host([expanded]) > .positioning-region .expand-collapse-glyph {
    transform: rotate(45deg);
  }
`;
const rtl = fast_element_1.css `
  .expand-collapse-glyph {
    transform: rotate(180deg);
  }
  :host(.nested) .expand-collapse-button {
    right: var(
      --expand-collapse-button-nested-width,
      calc(${index_1.heightNumber} * -1px)
    );
  }
  :host([selected])::after {
    right: calc(${fast_components_1.focusStrokeWidth} * 1px);
  }
  :host([expanded]) > .positioning-region .expand-collapse-glyph {
    transform: rotate(135deg);
  }
`;
/**
 * Tree item expand collapse button size CSS Partial
 * @public
 */
exports.expandCollapseButtonSize = fast_element_1.cssPartial `((${fast_components_1.baseHeightMultiplier} / 2) * ${fast_components_1.designUnit}) + ((${fast_components_1.designUnit} * ${fast_components_1.density}) / 2)`;
const expandCollapseHoverBehavior = fast_foundation_1.DesignToken.create('tree-item-expand-collapse-hover').withDefault((target) => {
    const recipe = fast_components_1.neutralFillStealthRecipe.getValueFor(target);
    return recipe.evaluate(target, recipe.evaluate(target).hover).hover;
});
const selectedExpandCollapseHoverBehavior = fast_foundation_1.DesignToken.create('tree-item-expand-collapse-selected-hover').withDefault((target) => {
    const baseRecipe = fast_components_1.neutralFillRecipe.getValueFor(target);
    const buttonRecipe = fast_components_1.neutralFillStealthRecipe.getValueFor(target);
    return buttonRecipe.evaluate(target, baseRecipe.evaluate(target).rest).hover;
});
/**
 * Styles for Tree Item
 * @public
 */
const treeItemStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('block')} :host {
      contain: content;
      position: relative;
      outline: none;
      color: ${fast_components_1.neutralForegroundRest};
      background: ${fast_components_1.neutralFillStealthRest};
      cursor: pointer;
      font-family: ${fast_components_1.bodyFont};
      --expand-collapse-button-size: calc(${index_1.heightNumber} * 1px);
      --tree-item-nested-width: 0;
    }

    :host(:focus) > .positioning-region {
      outline: none;
    }

    :host(:focus) .content-region {
      outline: none;
    }

    :host(:${fast_foundation_1.focusVisible}) .positioning-region {
      border: ${fast_components_1.accentFillFocus} calc((${fast_components_1.focusStrokeWidth}) * 1px) solid;
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      color: ${fast_components_1.neutralForegroundRest};
    }

    .positioning-region {
      display: flex;
      position: relative;
      box-sizing: border-box;
      border: transparent calc(${fast_components_1.strokeWidth} * 1px) solid;
      height: calc((${index_1.heightNumber} + 1) * 1px);
    }

    .positioning-region::before {
      content: '';
      display: block;
      width: var(--tree-item-nested-width);
      flex-shrink: 0;
    }

    .positioning-region:hover {
      background: ${fast_components_1.neutralFillStealthHover};
    }

    .positioning-region:active {
      background: ${fast_components_1.neutralFillStealthActive};
    }

    .content-region {
      display: inline-flex;
      align-items: center;
      white-space: nowrap;
      width: 100%;
      height: calc(${index_1.heightNumber} * 1px);
      margin-inline-start: calc(${fast_components_1.designUnit} * 2px + 8px);
      font-size: ${fast_components_1.typeRampBaseFontSize};
      line-height: ${fast_components_1.typeRampBaseLineHeight};
      font-weight: 400;
    }

    .items {
      display: none;
      /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
      font-size: calc(1em + (${fast_components_1.designUnit} + 16) * 1px);
    }

    .expand-collapse-button {
      background: none;
      border: none;
      outline: none;
      /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
      width: calc((${exports.expandCollapseButtonSize} + (${fast_components_1.designUnit} * 2)) * 1px);
      height: calc((${exports.expandCollapseButtonSize} + (${fast_components_1.designUnit} * 2)) * 1px);
      padding: 0;
      display: flex;
      justify-content: center;
      align-items: center;
      cursor: pointer;
      margin-left: 6px;
      margin-right: 6px;
    }

    .expand-collapse-glyph {
      /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
      width: 16px;
      height: 16px;
      transition: transform 0.1s linear;

      pointer-events: none;
      fill: currentcolor;
    }

    .start,
    .end {
      display: flex;
      fill: currentcolor;
    }

    ::slotted(svg) {
      /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
      width: 16px;
      height: 16px;
    }

    .start {
      /* TODO: horizontalSpacing https://github.com/microsoft/fast/issues/2766 */
      margin-inline-end: calc(${fast_components_1.designUnit} * 2px + 2px);
    }

    .end {
      /* TODO: horizontalSpacing https://github.com/microsoft/fast/issues/2766 */
      margin-inline-start: calc(${fast_components_1.designUnit} * 2px + 2px);
    }

    :host([expanded]) > .items {
      display: block;
    }

    :host([disabled]) .content-region {
      opacity: ${fast_components_1.disabledOpacity};
      cursor: ${fast_foundation_1.disabledCursor};
    }

    :host(.nested) .content-region {
      position: relative;
      margin-inline-start: var(--expand-collapse-button-size);
    }

    :host(.nested) .expand-collapse-button {
      position: absolute;
    }

    :host(.nested) .expand-collapse-button:hover {
      background: ${expandCollapseHoverBehavior};
    }

    :host([selected]) .positioning-region {
      background: ${fast_components_1.neutralFillRest};
    }

    :host([selected]) .expand-collapse-button:hover {
      background: ${selectedExpandCollapseHoverBehavior};
    }

    :host([selected])::after {
      /* The background needs to be calculated based on the selected background state
            for this control. We currently have no way of changing that, so setting to
            accent-foreground-rest for the time being */
      background: ${fast_components_1.accentForegroundRest};
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      content: '';
      display: block;
      position: absolute;
      top: calc((${index_1.heightNumber} / 4) * 1px);
      width: 3px;
      height: calc((${index_1.heightNumber} / 2) * 1px);
    }

    ::slotted(${context.tagFor(fast_foundation_1.TreeItem)}) {
      --tree-item-nested-width: 1em;
      --expand-collapse-button-nested-width: calc(${index_1.heightNumber} * -1px);
    }
  `.withBehaviors(new fast_components_1.DirectionalStyleSheetBehavior(ltr, rtl), fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        :host {
          forced-color-adjust: none;
          border-color: transparent;
          background: ${fast_web_utilities_1.SystemColors.Field};
          color: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        :host .content-region .expand-collapse-glyph {
          fill: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        :host .positioning-region:hover,
        :host([selected]) .positioning-region {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
        }
        :host .positioning-region:hover .content-region,
        :host([selected]) .positioning-region .content-region {
          color: ${fast_web_utilities_1.SystemColors.HighlightText};
        }
        :host .positioning-region:hover .content-region .expand-collapse-glyph,
        :host .positioning-region:hover .content-region .start,
        :host .positioning-region:hover .content-region .end,
        :host([selected]) .content-region .expand-collapse-glyph,
        :host([selected]) .content-region .start,
        :host([selected]) .content-region .end {
          fill: ${fast_web_utilities_1.SystemColors.HighlightText};
        }
        :host([selected])::after {
          background: ${fast_web_utilities_1.SystemColors.Field};
        }
        :host(:${fast_foundation_1.focusVisible}) .positioning-region {
          border-color: ${fast_web_utilities_1.SystemColors.FieldText};
          box-shadow: 0 0 0 2px inset ${fast_web_utilities_1.SystemColors.Field};
          color: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        :host([disabled]) .content-region,
        :host([disabled]) .positioning-region:hover .content-region {
          opacity: 1;
          color: ${fast_web_utilities_1.SystemColors.GrayText};
        }
        :host([disabled]) .content-region .expand-collapse-glyph,
        :host([disabled]) .content-region .start,
        :host([disabled]) .content-region .end,
        :host([disabled])
          .positioning-region:hover
          .content-region
          .expand-collapse-glyph,
        :host([disabled]) .positioning-region:hover .content-region .start,
        :host([disabled]) .positioning-region:hover .content-region .end {
          fill: ${fast_web_utilities_1.SystemColors.GrayText};
        }
        :host([disabled]) .positioning-region:hover {
          background: ${fast_web_utilities_1.SystemColors.Field};
        }
        .expand-collapse-glyph,
        .start,
        .end {
          fill: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        :host(.nested) .expand-collapse-button:hover {
          background: ${fast_web_utilities_1.SystemColors.Field};
        }
        :host(.nested) .expand-collapse-button:hover .expand-collapse-glyph {
          fill: ${fast_web_utilities_1.SystemColors.FieldText};
        }
      `));
exports.treeItemStyles = treeItemStyles;
//# sourceMappingURL=tree-item.styles.js.map